datetimeeditor — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

# datetimeeditor

class `camelot.view.controls.editors.datetimeeditor.` `DateTimeEditor`(parent, editable=True, nullable=True, field_name='datetime', **kwargs)

  Widget for editing date and time separated and with popups

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- controls »
- editors »

Comments
blog comments powered by Disqus